import { css, LitElement, html } from 'lit';
import { property, state } from 'lit/decorators.js';
import { UUIEvent } from '@umbraco-ui/uui-base/lib/events';
import { defineElement } from '@umbraco-ui/uui-base/lib/registration';

class UUIInputEvent extends UUIEvent {
}
UUIInputEvent.CHANGE = "change";

var __defProp = Object.defineProperty;
var __getOwnPropDesc = Object.getOwnPropertyDescriptor;
var __decorateClass = (decorators, target, key, kind) => {
  var result = kind > 1 ? void 0 : kind ? __getOwnPropDesc(target, key) : target;
  for (var i = decorators.length - 1, decorator; i >= 0; i--)
    if (decorator = decorators[i])
      result = (kind ? decorator(target, key, result) : decorator(result)) || result;
  if (kind && result)
    __defProp(target, key, result);
  return result;
};
class UUIInputElement extends LitElement {
  constructor() {
    super();
    this.placeholder = "";
    this.disabled = false;
    this._value = "";
    this.name = "";
    this.error = false;
    this._type = "text";
    this._internals = this.attachInternals();
    this.addEventListener("mousedown", () => {
      this.style.setProperty("--uui-show-focus-outline", "0");
    });
    this.addEventListener("blur", () => {
      this.style.setProperty("--uui-show-focus-outline", "");
    });
  }
  get value() {
    return this._value;
  }
  set value(newValue) {
    this._value = newValue;
    if ("ElementInternals" in window && "setFormValue" in window.ElementInternals.prototype) {
      this._internals.setFormValue(this._value);
    }
  }
  get type() {
    return this._type;
  }
  set type(value) {
    this._type = value;
  }
  focus() {
    var _a;
    ((_a = this.shadowRoot) == null ? void 0 : _a.querySelector("#input")).focus();
  }
  onInput(e) {
    this.value = e.target.value;
  }
  onChange() {
    this.dispatchEvent(new UUIInputEvent(UUIInputEvent.CHANGE));
  }
  renderPrepend() {
    return html`<slot name="prepend"></slot>`;
  }
  renderAppend() {
    return html`<slot name="append"></slot>`;
  }
  render() {
    return html`
      ${this.renderPrepend()}
      <input
        id="input"
        .type=${this.type}
        .value=${this.value}
        .name=${this.name}
        placeholder=${this.placeholder}
        aria-label=${this.label}
        .disabled=${this.disabled}
        @input=${this.onInput}
        @change=${this.onChange} />
      ${this.renderAppend()}
    `;
  }
}
UUIInputElement.styles = [
  css`
      :host {
        position: relative;
        display: inline-flex;
        align-items: center;
        height: var(--uui-size-11,33px);
        font-size: 15px;
        text-align: left;
        box-sizing: border-box;
        background-color: var(
          --uui-input-background-color,
          var(--uui-interface-surface,#fefefe)
        );
        border: var(--uui-input-border-width, 1px) solid
          var(--uui-input-border-color, var(--uui-interface-border,#c4c4c4));
      }
      :host(:hover) {
        border-color: var(
          --uui-input-border-color-hover,
          var(--uui-interface-border-hover,rgb(179, 179, 179))
        );
      }
      /* TODO: Fix so we dont get double outline when there is focus on things in the slot. */
      :host(:focus-within) {
        border-color: var(
          --uui-input-border-color-focus,
          var(--uui-interface-border-focus,rgb(179, 179, 179))
        );
        outline: calc(2px * var(--uui-show-focus-outline, 1)) solid
          var(--uui-interface-outline,#3879ff);
      }
      :host(:focus) {
        border-color: var(
          --uui-input-border-color-focus,
          var(--uui-interface-border-focus,rgb(179, 179, 179))
        );
      }
      :host([error]) {
        border-color: var(--uui-look-danger-border,#d42054);
      }
      :host([disabled]) {
        background-color: var(
          --uui-input-background-color-disabled,
          var(--uui-interface-surface-disabled,rgb(228, 228, 228))
        );
        border: 1px solid
          var(
            --uui-input-border-color-disabled,
            var(--uui-interface-border-disable)
          );

        color: var(--uui-interface-contrast-disabled,rgb(115, 113, 110));
      }

      input {
        font-family: inherit;
        padding: var(--uui-size-1,3px) var(--uui-size-space-3,9px);
        font-size: 15px;
        color: inherit;
        border-radius: 0;
        box-sizing: border-box;
        border: none;
        background: none;
        width: 100%;
        text-align: inherit;
        outline: none;
      }

      input::-moz-placeholder {
        -moz-transition: opacity 120ms;
        transition: opacity 120ms;
      }

      input:-ms-input-placeholder {
        -ms-transition: opacity 120ms;
        transition: opacity 120ms;
      }

      input::placeholder {
        transition: opacity 120ms;
      }
      input:focus::-moz-placeholder {
        opacity: 0;
      }
      input:focus:-ms-input-placeholder {
        opacity: 0;
      }
      input:focus::placeholder {
        opacity: 0;
      }

      /* TODO: make sure color looks good, or remove it as an option as we want to provide color-picker component */
      input[type='color'] {
        width: 30px;
        padding: 0;
        border: none;
      }

      ::slotted(uui-input) {
        height: 100%;
        --uui-input-border-width: 0;
      }
    `
];
UUIInputElement.formAssociated = true;
__decorateClass([
  property({ type: String })
], UUIInputElement.prototype, "label", 2);
__decorateClass([
  property()
], UUIInputElement.prototype, "placeholder", 2);
__decorateClass([
  property({ type: Boolean, reflect: true })
], UUIInputElement.prototype, "disabled", 2);
__decorateClass([
  state()
], UUIInputElement.prototype, "_value", 2);
__decorateClass([
  property()
], UUIInputElement.prototype, "value", 1);
__decorateClass([
  property({ type: String })
], UUIInputElement.prototype, "name", 2);
__decorateClass([
  property({ type: Boolean, reflect: true })
], UUIInputElement.prototype, "error", 2);
__decorateClass([
  property({ type: String })
], UUIInputElement.prototype, "_type", 2);

defineElement("uui-input", UUIInputElement);
