import { LitElement } from 'lit';
export declare type InputType = 'text' | 'tel' | 'url' | 'email' | 'password' | 'date' | 'month' | 'week' | 'time' | 'datetime-local' | 'number' | 'color';
/**
 * Custom element wrapping the native input element.This is a formAssociated element, meaning it can participate in a native HTMLForm. A name:value pair will be submitted.
 * @element uui-input
 * @slot input label - for the input label text.
 * @slot prepend - for components to render to the left of the input.
 * @slot append - for components to render to the right of the input.
 * @fires UUIInputEvent#change on change
 * @fires InputEvent#input on input
 * @fires KeyboardEvent#keyup on keyup
 */
export declare class UUIInputElement extends LitElement {
    static styles: import("lit").CSSResult[];
    /**
     * Label for input element.
     * @type {string}
     * @attr
     */
    label: string;
    /**
     * Defines the input placeholder.
     * @type {string}
     * @attr
     * @default ''
     */
    placeholder: string;
    /**
     * Disables the input.
     * @type {boolean}
     * @attr
     * @default false
     */
    disabled: boolean;
    private _value;
    /**
     * This is a value property of the uui-input.
     * @type {string}
     * @attr
     * @default ''
     */
    get value(): string;
    set value(newValue: string);
    /**
     * This is a name property of the `<uui-input>` component. It reflects the behaviour of the native `<input />` element and its name attribute.
     * @type {string}
     * @attr
     * @default ''
     */
    name: string;
    /**
     * Set to true if the component should have an error state.
     * @type {boolean}
     * @attr
     * @default false
     */
    error: boolean;
    /**
     * This property specifies the type of input that will be rendered.
     * @type {'text' | 'tel'| 'url'| 'email'| 'password'| 'date'| 'month'| 'week'| 'time'| 'datetime-local'| 'number'| 'color'}
     * @attr
     * @default text
     */
    private _type;
    get type(): InputType;
    set type(value: InputType);
    /**
     * This is a static class field indicating that the element is can be used inside a native form and participate in its events. It may require a polyfill, check support here https://developer.mozilla.org/en-US/docs/Web/API/HTMLElement/attachInternals.  Read more about form controls here https://web.dev/more-capable-form-controls/
     * @type {boolean}
     */
    static readonly formAssociated = true;
    private _internals;
    constructor();
    /**
     * This method enables <label for="..."> to focus the input
     */
    focus(): void;
    private onInput;
    private onChange;
    protected renderPrepend(): import("lit-html").TemplateResult<1>;
    protected renderAppend(): import("lit-html").TemplateResult<1>;
    render(): import("lit-html").TemplateResult<1>;
}
